==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbDatabaseInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Database specific information for SQL to Azure SQL DB migration task inputs
 * @property makeSourceDbReadOnly Whether to set database read only before migration
 * @property name Name of the database
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Name of target database. Note: Target database will be truncated before starting migration.
 */
public data class MigrateSqlServerSqlDbDatabaseInputResponse(
    public val makeSourceDbReadOnly: Boolean? = null,
    public val name: String? = null,
    public val tableMap: Map<String, String>? = null,
    public val targetDatabaseName: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbDatabaseInputResponse):
            MigrateSqlServerSqlDbDatabaseInputResponse = MigrateSqlServerSqlDbDatabaseInputResponse(
            makeSourceDbReadOnly = javaType.makeSourceDbReadOnly().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            tableMap = javaType.tableMap().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            targetDatabaseName = javaType.targetDatabaseName().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlDbDatabaseInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Database specific information for SQL to Azure SQL DB migration task inputs
 * @property makeSourceDbReadOnly Whether to set database read only before migration
 * @property name Name of the database
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Name of target database. Note: Target database will be truncated before starting migration.
 */
public data class MigrateSqlServerSqlDbDatabaseInputResponse(
    public val makeSourceDbReadOnly: Boolean? = null,
    public val name: String? = null,
    public val tableMap: Map<String, String>? = null,
    public val targetDatabaseName: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlDbDatabaseInputResponse): MigrateSqlServerSqlDbDatabaseInputResponse = MigrateSqlServerSqlDbDatabaseInputResponse(
            makeSourceDbReadOnly = javaType.makeSourceDbReadOnly().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            tableMap = javaType.tableMap().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            targetDatabaseName = javaType.targetDatabaseName().map({ args0 -> args0 }).orElse(null),
        )
    }
}
